@@ -1,9 +1,10 @@
 use 5.008001;
 use strict;
+use warnings;
 use Plack::Request ();
 
 package Plack::Middleware::MethodOverride;
-$Plack::Middleware::MethodOverride::VERSION = '0.13';
+$Plack::Middleware::MethodOverride::VERSION = '0.14';
 # ABSTRACT: Override REST methods to Plack apps via POST
 
 use parent 'Plack::Middleware';
@@ -25,10 +26,10 @@ sub call {
     my $meth = $env->{'plack.original_request_method'} = $env->{REQUEST_METHOD};
 
     if ($meth and uc $meth eq 'POST') {
+        no warnings 'uninitialized';
         my $override = uc (
             $env->{$self->header}
             or $env->{QUERY_STRING} && Plack::Request->new($env)->query_parameters->{$self->param}
-            or ''
         );
         $env->{REQUEST_METHOD} = $override if exists $allowed_method{$override};
     }
@@ -60,7 +61,7 @@ Plack::Middleware::MethodOverride - Override REST methods to Plack apps via POST
 
 =head1 Version
 
-version 0.13
+version 0.14
 
 =head1 Synopsis
 
@@ -98,21 +99,21 @@ what method it actually meant. That is, as long as it meant one of these:
 
 =over
 
-=item GET
+=item * GET
 
-=item POST
+=item * POST
 
-=item HEAD
+=item * HEAD
 
-=item PUT
+=item * PUT
 
-=item DELETE
+=item * DELETE
 
-=item OPTIONS
+=item * OPTIONS
 
-=item TRACE
+=item * TRACE
 
-=item CONNECT
+=item * CONNECT
 
 =back
 
